@@ -2,7 +2,7 @@
 Author: LetMeFly
 Date: 2022-01-24 16:04:55
 LastEditors: LetMeFly
-LastEditTime: 2022-02-21 17:11:20
+LastEditTime: 2022-05-02 12:37:41
 '''
 import requests
 from bs4 import BeautifulSoup
@@ -25,9 +25,9 @@ def getASourceCode_0(cid: str, pid_str: str, cookies: requests.cookies.RequestsC
     url = f"{base_url}status.php?cid={cid}&problem_id={pid_str}&user_id=&language=1&jresult=4&showsim=0"
     response = requests.get(url, cookies=cookies)
     soup = BeautifulSoup(response.text, features)
-    table = soup.find('table', attrs={"id": "vueAppFuckSafari"})
+    table = soup.find('table', attrs={"id": "result-tab"})
     tr = table.find('tbody').find('tr')
-    td = tr.find_all('td')[6]
+    td = tr.find_all('td')[7]
     a = td.find_all('a')[1]
     from . import Config
     base_url = Config.get_info("base_url")
@@ -48,14 +48,14 @@ def getASourceCode(cid: str, pid: str, cookies: requests.cookies.RequestsCookieJ
     response_problem_in_content = requests.get(url_problem_in_content, cookies=cookies)
     soup_problem_in_content = BeautifulSoup(response_problem_in_content.text, features)
     a_problem_in_content = soup_problem_in_content.find_all("a", attrs={"class": "small"})
-    real_pid = str(a_problem_in_content[2].get("href")).split("id=")[1].split("&")[0]
+    real_pid = str(a_problem_in_content[3].get("href")).split("id=")[1].split("&")[0]
     # print(real_pid)
     url = f"{base_url}status.php?problem_id={real_pid}&user_id=&language=1&jresult=4&showsim=0"
     response = requests.get(url, cookies=cookies)
     soup = BeautifulSoup(response.text, features)
-    table = soup.find('table', attrs={"id": "vueAppFuckSafari"})
+    table = soup.find('table', attrs={"id": "result-tab"})
     tr = table.find('tbody').find('tr')
-    td = tr.find_all('td')[6]
+    td = tr.find_all('td')[7]
     a = td.find_all('a')[1]
     href = base_url + a.get('href')
     response = requests.get(href, cookies=cookies)
@@ -75,7 +75,8 @@ def getASourceCodeAndChange(cid: str, pid: str, cookies: requests.cookies.Reques
     except:
     # else:
         pid_str = FromPidToChar.i2s(pid)
-        code = getASourceCode_0(cid=cid, pid_str=pid, cookies=cookies)
+        # code = getASourceCode_0(cid=cid, pid_str=pid_str, cookies=cookies)
+        code = getASourceCode(cid=cid, pid=pid, cookies=cookies)
     pre = f"""// LetMeFly_PySubmiter
 #include <bits/stdc++.h>
 using namespace std;
